==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/misc1/randlib/rngu3.c <==
/* src/misc1/randlib/rngu3.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     RANDOM NUMBER GENERATOR (? METHOD BY KUNUTH) */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
doublereal rngu3_(integer *iseed)
{
    /* Initialized data */

    static logical lfirst = TRUE_;

    /* System generated locals */
    real ret_val;

    /* Local variables */
    static integer i__, k, ma[55], ii, mj, mk, inext;
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);
    static integer inextp;

    if (*iseed != 0) {
	mj = 161803398 - abs(*iseed);
	mj %= 1000000000;
	ma[54] = mj;
	mk = 1;
	for (i__ = 1; i__ <= 54; ++i__) {
	    ii = i__ * 21 % 55;
	    ma[ii - 1] = mk;
	    mk = mj - mk;
	    if (mk < 0) {
		mk += 1000000000;
	    }
	    mj = ma[ii - 1];
/* L100: */
	}
	for (k = 1; k <= 4; ++k) {
	    for (i__ = 1; i__ <= 55; ++i__) {
		ma[i__ - 1] -= ma[(i__ + 30) % 55];
		if (ma[i__ - 1] < 0) {
		    ma[i__ - 1] += 1000000000;
		}
/* L200: */
	    }
/* L300: */
	}
	inext = 0;
	inextp = 31;
	*iseed = 0;
	lfirst = FALSE_;
    }
    if (lfirst) {
	msgdmp_("E", "RNGU3", "ISEED MUST BE > 0 FOR 1ST CALL.", (ftnlen)1, (
		ftnlen)5, (ftnlen)31);
    }
    ++inext;
    if (inext == 56) {
	inext = 1;
    }
    ++inextp;
    if (inextp == 56) {
	inextp = 1;
    }
    mj = ma[inext - 1] - ma[inextp - 1];
    if (mj < 0) {
	mj += 1000000000;
    }
    ma[inext - 1] = mj;
    ret_val = mj * 1e-9f;
    return ret_val;
} /* rngu3_ */

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/misc1/randlib/rngu3.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     RANDOM NUMBER GENERATOR (? METHOD BY KUNUTH) */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
real rngu3_(integer *iseed)
{
    /* Initialized data */

    static logical lfirst = TRUE_;

    /* System generated locals */
    real ret_val;

    /* Local variables */
    static integer i__, k, ma[55], ii, mj, mk, inext;
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);
    static integer inextp;

    if (*iseed != 0) {
	mj = 161803398 - abs(*iseed);
	mj %= 1000000000;
	ma[54] = mj;
	mk = 1;
	for (i__ = 1; i__ <= 54; ++i__) {
	    ii = i__ * 21 % 55;
	    ma[ii - 1] = mk;
	    mk = mj - mk;
	    if (mk < 0) {
		mk += 1000000000;
	    }
	    mj = ma[ii - 1];
/* L100: */
	}
	for (k = 1; k <= 4; ++k) {
	    for (i__ = 1; i__ <= 55; ++i__) {
		ma[i__ - 1] -= ma[(i__ + 30) % 55];
		if (ma[i__ - 1] < 0) {
		    ma[i__ - 1] += 1000000000;
		}
/* L200: */
	    }
/* L300: */
	}
	inext = 0;
	inextp = 31;
	*iseed = 0;
	lfirst = FALSE_;
    }
    if (lfirst) {
	msgdmp_("E", "RNGU3", "ISEED MUST BE > 0 FOR 1ST CALL.", (ftnlen)1, (
		ftnlen)5, (ftnlen)31);
    }
    ++inext;
    if (inext == 56) {
	inext = 1;
    }
    ++inextp;
    if (inextp == 56) {
	inextp = 1;
    }
    mj = ma[inext - 1] - ma[inextp - 1];
    if (mj < 0) {
	mj += 1000000000;
    }
    ma[inext - 1] = mj;
    ret_val = mj * 1e-9f;
    return ret_val;
} /* rngu3_ */
